summaryrefslogtreecommitdiffstats
path: root/generic/tkImgPhoto.c
diff options
context:
space:
mode:
authordkf <donal.k.fellows@manchester.ac.uk>2002-06-14 14:07:50 (GMT)
committerdkf <donal.k.fellows@manchester.ac.uk>2002-06-14 14:07:50 (GMT)
commit02232e9bfade579d304edb4b0661280a64593a93 (patch)
tree275c5586d549746067683749acc5bdee77a54a73 /generic/tkImgPhoto.c
parent8abf69416e48492ccda18dcfc6e8adf9d33d0a32 (diff)
downloadtk-02232e9bfade579d304edb4b0661280a64593a93.zip
tk-02232e9bfade579d304edb4b0661280a64593a93.tar.gz
tk-02232e9bfade579d304edb4b0661280a64593a93.tar.bz2
Changed some _Old and _OLD to more descriptive terms.
Diffstat (limited to 'generic/tkImgPhoto.c')
-rw-r--r--generic/tkImgPhoto.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/generic/tkImgPhoto.c b/generic/tkImgPhoto.c
index 032ce89..7f82a77 100644
--- a/generic/tkImgPhoto.c
+++ b/generic/tkImgPhoto.c
@@ -16,7 +16,7 @@
* Department of Computer Science,
* Australian National University.
*
- * RCS: @(#) $Id: tkImgPhoto.c,v 1.31 2002/06/14 13:35:48 dkf Exp $
+ * RCS: @(#) $Id: tkImgPhoto.c,v 1.32 2002/06/14 14:07:51 dkf Exp $
*/
#include "tkInt.h"
@@ -5505,16 +5505,16 @@ ImgPhotoPostscript(clientData, interp, tkwin, psInfo,
/*
*----------------------------------------------------------------------
*
- * Tk_PhotoPutBlock_Old, Tk_PhotoPutZoomedBlock_Old --
+ * Tk_PhotoPutBlock_NoComposite, Tk_PhotoPutZoomedBlock_NoComposite --
*
* These backward-compatability functions just exist to fill slots in
* stubs table. For the behaviour of *_Old, refer to the
* corresponding function without the extra suffix.
*
*----------------------------------------------------------------------
*/
void
-Tk_PhotoPutBlock_Old(handle, blockPtr, x, y, width, height)
+Tk_PhotoPutBlock_NoComposite(handle, blockPtr, x, y, width, height)
Tk_PhotoHandle handle;
Tk_PhotoImageBlock *blockPtr;
int x, y, width, height;
@@ -5524,8 +5524,8 @@ Tk_PhotoPutBlock_Old(handle, blockPtr, x, y, width, height)
}
void
-Tk_PhotoPutZoomedBlock_Old(handle, blockPtr, x, y, width, height,
- zoomX, zoomY, subsampleX, subsampleY)
+Tk_PhotoPutZoomedBlock_NoComposite(handle, blockPtr, x, y, width, height,
+ zoomX, zoomY, subsampleX, subsampleY)
Tk_PhotoHandle handle;
Tk_PhotoImageBlock *blockPtr;
int x, y, width, height, zoomX, zoomY, subsampleX, subsampleY;
@@ -5505,16 +5505,16 @@ ImgPhotoPostscript(clientData, interp, tkwin, psInfo,
*
* These backward-compatability functions just exist to fill slots in
- * stubs table. For the behaviour of *_Old, refer to the
+ * stubs table. For the behaviour of *_NoComposite, refer to the
* corresponding function without the extra suffix.
*